# -*- coding: utf-8 -*-
"""The package *pyrdbg* automates and extends the remote debugging for *Eclipse*/*PyDev*, and others.

"""
from __future__ import absolute_import
import sys


__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2019 Arno-Can Uestuensoez" \
                " @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.2.21'
__uuid__ = '7f464182-b723-4e6e-869d-80a16b9cfaca'

__docformat__ = "restructuredtext en"


class PyRdbgError(Exception):
    """Generic RDBG error."""

    def __init__(self, *argss, **kw):
#        super(PyRdbgError, self).__init__(*argss, **kw)
        Exception.__init__(self, *argss, **kw)


class RdbgNetworkError(PyRdbgError):
    """RDBG network error."""

    def __init__(self, *argss, **kw):
        super(RdbgNetworkError, self).__init__(*argss, **kw)


# pylint: disable-msg=W0105

# fetch initial state early - seems to be a reliable and simple evaluated criteria
if sys.modules.get('pydevd'):  # already loaded
    callfromPyDevDbg = True    
else:
    callfromPyDevDbg = False


#: Debugs the debugging.
my_dbg_self = 0

# pre-fetch debugging flag for the rdbg itself
# early detection works for space separated values only
# the '=' separator is worked out in the standard options processing
if '--rdbg-self' in sys.argv:
    l = len(sys.argv)
    for i in range(l):
        if sys.argv[i] in ('--rdbg-self', '-rdbg-self'):
            if l > i:
                try:
                    _v = int(sys.argv[i + 1])
                except ValueError:
                    my_dbg_self += 1
                except IndexError:
                    my_dbg_self += 1
                else:
                    my_dbg_self = _v
            else:
                my_dbg_self += 1
else:
    my_dbg_self = 0


#: Verbose the display.
my_verb_self = 0

# pre-fetch verbose display flag for the rdbg itself
# early detection works for space separated values only
# the '=' separator is worked out in the standard options processing
if '--rdbg-verb' in sys.argv:
    l = len(sys.argv)
    for i in range(l):
        if sys.argv[i] in ('--rdbg-verb', '-rdbg-verb'):
            if l > i:
                try:
                    _v = int(sys.argv[i + 1])
                except ValueError:
                    my_verb_self += 1
                except IndexError:
                    my_verb_self += 1
                else:
                    my_verb_self = _v
            else:
                my_verb_self += 1
else:
    my_verb_self = 0


