# -*- coding: utf-8 -*-
"""Debugging stub for the validation of *PyRDBG* itself.
"""
from __future__ import absolute_import
from __future__ import print_function


# debug
import sys
import os

from sourceinfo.fileinfo import getcaller_package_filename, getcaller_package_pathname, getcaller_linenumber


__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2016-2019 Arno-Can Uestuensoez" \
                " @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.2.21'
__uuid__ = '7f464182-b723-4e6e-869d-80a16b9cfaca'

__docformat__ = "restructuredtext en"


if __name__ == '__main__':
    
    sys.stdout.write(
        '\nrdbgprobe:0:STAGE(0) - initialize process\n')
    
    sys.stdout.write(
        '\nrdbgprobe:0: %s : %s\n' % (
            str(getcaller_package_pathname()),
            str(getcaller_package_filename())
            )
        )
    
    sys.stdout.write(
        'rdbgprobe:0: %s : %s\n' % (
            str(os.path.abspath(__file__)),
            str(getcaller_linenumber())
            )
        )

    sys.stdout.write('rdbgprobe:0:start basic validation of PyRDBG\n')
    
    if '--debug' in sys.argv:
        sys.stderr.write('rdbgprobe:sys.executable = %s\n' % (str(sys.executable)))
    
        sys.stderr.write('rdbgprobe:sys.version    = [\n')
        for x in sys.version.split(os.linesep):
            sys.stderr.write('rdbgprobe:sys.version    :   %s\n' % (x))
        sys.stderr.write('rdbgprobe:sys.version    : ]\n' )
    
        sys.stderr.write('rdbgprobe:sys.argv       = [\n' )
        for x in sys.argv:
            sys.stderr.write('rdbgprobe:sys.argv       :   %s\n' % (x))
        sys.stderr.write('rdbgprobe:sys.argv       : ]\n' )
    
        sys.stderr.write('rdbgprobe:sys.path       = [\n' )
        for x in sys.path:
            sys.stderr.write('rdbgprobe:sys.path       :   %s\n' % (x))
        sys.stderr.write('rdbgprobe:sys.path       : ]\n' )
    
        sys.stderr.write('\n' )
    
        import platform
        sys.stderr.write('rdbgprobe:platform.node = %s\n' % (str(platform.node())))
        sys.stderr.write('\n' )
    
    
    #
    # Checks 'sys.argv' for '--rdbg', if present,
    # than loads and executes 'rdbg'.
    # For help use options '-h' or '--rdbg-help'.
    #
    sys.stdout.write('rdbgprobe:0:import rdbg.start\n')
    from rdbg.start import start_remote_debug
    
    sys.stdout.write(
        '\nrdbgprobe:1:STAGE(1) - initialize rdbg and start debugging - starttrace\n')
    
    sys.stdout.write('rdbgprobe:1:start remote debug\n')
    sys.stdout.write('rdbgprobe:1:force load with defaults, simulates "--rdbg" switch\n')
    sys.stdout.write('rdbgprobe:1:"--rdbg" still to be used for non-standard hosts and ports\n')
    sys.stdout.write('rdbgprobe:1:use "--rdbg-self" for additional traces on *PyRDBG*\n')
    sys.stdout.write('rdbgprobe:1:"--rdbg-help" for help on *PyRDBG*\n')
    start_remote_debug(
        appname='rdbgprobe',
        forceload=True
        )
    sys.stdout.write('rdbgprobe:2:rdbg initialization complete\n')
    
    
    #####################################################################
    #                                                                   #
    #                PyRDBG is available from here on                   #
    #                                                                   #
    #####################################################################
    
    
    
    sys.stdout.write(
        '\nrdbgprobe:2:STAGE(2) - enabled rdbg for application debugging\n')
    
    if '--debug' in sys.argv:
        from rdbg.shared import PYDEVD
        sys.stderr.write('rdbgprobe:2:pydevd            = %s\n' % (str(PYDEVD.pydevd)))
    
    sys.stdout.write(
        '\nrdbgprobe:3:STAGE(3) - start remote debugging of apps here\n\n')
    #
    # dummy code
    #
    a = 123
    b = 234  # set a breakpoint here
    c = 345
    
    print("rdbgprobe:appcode:" + str(a))
    print("rdbgprobe:appcode:" + str(b)) # and here
    print("rdbgprobe:appcode:" + str(c))
    
    sys.stdout.write(
        '\nrdbgprobe:4:STAGE(4) - shutdown process\n\n')
    sys.stdout.write('\nrdbgprobe:4:finish remote debugging\n')
    sys.stdout.write('rdbgprobe:4:exit process\n')
