# -*- coding: utf-8 -*-
"""For now - shared variables between modules in order to avoid circular inclusion."""
from __future__ import absolute_import

import os
import sys

from filesysobjects.userdata import gethome
from sourceinfo.objectinfo import getcaller_module_name

from platformids import RTE, RTE_WIN32
from platformids.dist.cygwin import RTE_CYGWINNT

__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2019 Arno-Can Uestuensoez" \
                " @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.2.21'
__uuid__ = '7f464182-b723-4e6e-869d-80a16b9cfaca'

__docformat__ = "restructuredtext en"


try:
    if argv_org:  # @UndefinedVariable
        pass
except:
    argv_org = sys.argv[:]

#: Platform specific default root for eclipse.
_rdbgroot_default = ''

if RTE & RTE_CYGWINNT == RTE_CYGWINNT:
    _rdbgroot_default = "/cygdrive/c/eclipse"
elif RTE & RTE_WIN32 == RTE_WIN32:
    _rdbgroot_default = "C:\eclipse"
# elif RTE & (RTE_LINUX | RTE_DARWIN | RTE_BSD | RTE_SOLARIS):
else:
    _rdbgroot_default = gethome()  + os.sep + 'eclipse'

#: Platform specific path to the 'pydevd' directory.
_rdbgpath_default = []

#: The source-path-map for remote debugging by *PATHS_FROM_ECLIPSE_TO_PYTHON*.
_rdbgsrcmap_default = []

#: The separator for the single-string variant of the source-path-map.
_rdbgsrcmapsep_default = ';'

#: Default eclipse sub path.
_rdbgsub_default = "org.python.pydev[._][^0-9]*[0-9]*.[0-9]*.[0-9]*[.0-9]*[/\\\\]pysrc[/\\\\]pydevd.py"
 
#: Control of forwarding the debugging enabled state.
#: Possible values are:
#:  
#:     hopcnt: The nested subprocesses to be debugged.
#:  
#:         hopcnt >=0 : The number of nested subprocess
#:             hops to be debugged.
#:  
#:         hopcnt <0 : The number of nested subprocess
#:             hops NOT to be debugged.
#:  
#:     'all': Debug all nested levels of subprocesses.
#:  
#:     label: Activate remote debug for the process with the previously
#:         assigned label only.
#:  
#:     label = [label-lst]: List of labels.
#:  
_rdbgfwd_default = 0
 
#: The default label to be used for forwarding.
_rdbglabel_default = getcaller_module_name()
 
#: The default values for the peer RemoteDebugServer as defined by PyDev.
_rdbg_default = "localhost:5678"
 
#: The cached options from sys.argv by checkandremove_rdbgoptions.
rdbgoptions = None

#: Forces test mode, enables the setting of partially erroneous parameters.
_pderd_inTestMode_suppress_init = False

#: Testflags
_rdbgtestflags = []

#: Valid values for testflags.
_rdbgtestflags_valid = [
    'ignorePydevd',
    'ignorePydevdSysPath',
    'ignorePydevdCallParam',
]

# suppress the removal of the options, for test only
if '--rdbg-keep-argv' in sys.argv:
    _rdbg_keep_argv = True
else:
    _rdbg_keep_argv = False

#: The shared proxy-controller, used by all modules.
PYDEVD = None

#: The proxy-module of PyDev.
pydevd_module = None
